==> maDB_1.6.0.tar.gz: maDB/man/Similarity-class.Rd <==
\name{Similarity-class}
\docType{class}
\alias{Similarity-class}
\alias{getData,Similarity-method}
\alias{getData}
\alias{getDistances,Similarity-method}
\alias{getDistances}
\alias{plot,Similarity-method}
\alias{print,Similarity-method}
\alias{sort,Similarity-method}

\title{Class "Similarity" }
\description{This class holds information about the similarity between a vector and another one (or the rows or columns of a numerical matrix). An instance of this class will be returned as the result of the \code{\link{dbSearchSimilarPattern}} function. So this object holds then information about the similarity (calculated with one of the different distance measurement functions (pearson, euclidian, spearman)) between a template gene pattern and a set of other gene expression or regulation patterns.}
\section{Objects from the Class}{
The function \code{\link{dbSearchSimilarPattern}} returns an instance of this class.
}
\section{Slots}{
  \describe{
    \item{\code{distances}:}{Object of class \code{"numeric"}, this vector represents the distance (similarity) between numerical vectors.}
    \item{\code{distance.metric}:}{Object of class \code{"character"}, the distance metric used to calculate the similarity.}
    \item{\code{data}:}{Object of class \code{"matrix"}, the data matrix containing the values with which the template was compared.}
    \item{\code{template}:}{Object of class \code{"numeric"}, the template vector.}
    \item{\code{template.id}:}{Object of class \code{"character"}, the id of the template (if no custom template was used).}
  }
}
\section{Methods}{
  \describe{
    \item{getData}{\code{signature(object = "Similarity")}: returns the data matrix.}
    \item{getDistances}{\code{signature(object = "Similarity")}: returns the distances.}
    \item{plot}{\code{signature(x = "Similarity")}: plots the template and the 5 top matching vectors (see \code{\link{plotSimilarity}} for more options).}
    \item{print}{\code{signature(x = "Similarity")}: generic print function for the class Similarity.}
    \item{sort}{\code{signature(x = "Similarity")}: sorts the data ascending or descending according to the distance.}
  }
}
\author{Johannes Rainer}

\seealso{
  \code{\link{dbSearchSimilarPattern}}
  \code{\link{plotSimilarity}}
}
\keyword{classes}

==> maDB_1.12.0.tar.gz: maDB/man/Similarity-class.Rd <==
\name{Similarity-class}
\docType{class}
\alias{Similarity-class}
\alias{getData,Similarity-method}
\alias{getData}
\alias{getDistances,Similarity-method}
\alias{getDistances}
\alias{plot,Similarity-method}
\alias{print,Similarity-method}
\alias{sort,Similarity-method}

\title{Class "Similarity" }
\description{This class holds information about the similarity between a vector and another one (or the rows or columns of a numerical matrix). An instance of this class will be returned as the result of the \code{\link{dbSearchSimilarPattern}} function. This object holds then information about the similarity (calculated with one of the different distance measurement functions (pearson, euclidian, spearman)) between a template gene pattern and a set of other gene expression or regulation patterns.}
\section{Objects from the Class}{
The function \code{\link{dbSearchSimilarPattern}} returns an instance of this class.
}
\section{Slots}{
  \describe{
    \item{\code{distances}:}{Object of class \code{"numeric"}, this vector represents the distance (similarity) between numerical vectors.}
    \item{\code{distance.metric}:}{Object of class \code{"character"}, the distance metric used to calculate the similarity.}
    \item{\code{data}:}{Object of class \code{"matrix"}, the data matrix containing the values with which the template was compared.}
    \item{\code{template}:}{Object of class \code{"numeric"}, the template vector.}
    \item{\code{template.id}:}{Object of class \code{"character"}, the id of the template (if no custom template was used).}
  }
}
\section{Methods}{
  \describe{
    \item{getData}{\code{signature(object = "Similarity")}: returns the data matrix.}
    \item{getDistances}{\code{signature(object = "Similarity")}: returns the distances.}
    \item{plot}{\code{signature(x = "Similarity")}: plots the template and the 5 top matching vectors (see \code{\link{plotSimilarity}} for more options).}
    \item{print}{\code{signature(x = "Similarity")}: generic print function for the class Similarity.}
    \item{sort}{\code{signature(x = "Similarity")}: sorts the data ascending or descending according to the distance.}
  }
}
\author{Johannes Rainer}

\seealso{
  \code{\link{dbSearchSimilarPattern}}
  \code{\link{plotSimilarity}}
}
\keyword{classes}
